==> quore-0.2.4.tgz: quore-0.2.4/include/binds.h <==
#define ENGINE_BINDS " \
bind \"TAB\" \"+showscores\"; \
bind \"ENTER\" \"+jump\"; \
bind \"ESCAPE\" \"togglemenu\"; \
bind \"SPACE\" \"+jump\"; \
bind \"+\" \"sizeup\"; \
bind \",\" \"+moveleft\"; \
bind \"-\" \"sizedown\"; \
bind \".\" \"+moveright\"; \
bind \"/\" \"impulse 10\"; \
bind \"0\" \"impulse 0\"; \
bind \"1\" \"impulse 1\"; \
bind \"2\" \"impulse 2\"; \
bind \"3\" \"impulse 3\"; \
bind \"4\" \"impulse 4\"; \
bind \"5\" \"impulse 5\"; \
bind \"6\" \"impulse 6\"; \
bind \"7\" \"impulse 7\"; \
bind \"8\" \"impulse 8\"; \
bind \"=\" \"sizeup\"; \
bind \"\\\" \"+mlook\"; \
bind \"`\" \"toggleconsole\"; \
bind \"a\" \"+lookup\"; \
bind \"c\" \"+movedown\"; \
bind \"d\" \"+moveup\"; \
bind \"m\" \"menu_maps\"; \
bind \"s\" \"screenshot\"; \
bind \"t\" \"messagemode\"; \
bind \"z\" \"zoom_in\"; \
bind \"~\" \"toggleconsole\"; \
bind \"UPARROW\" \"+forward\"; \
bind \"DOWNARROW\" \"+back\"; \
bind \"LEFTARROW\" \"+moveleft\"; \
bind \"RIGHTARROW\" \"+moveright\"; \
bind \"ALT\" \"+strafe\"; \
bind \"CTRL\" \"+jump\"; \
bind \"SHIFT\" \"+speed\"; \
bind \"F1\" \"help\"; \
bind \"F2\" \"menu_save\"; \
bind \"F3\" \"menu_load\"; \
bind \"F4\" \"menu_options\"; \
bind \"F5\" \"menu_multiplayer\"; \
bind \"F6\" \"echo Quicksaving...; wait; save quick\"; \
bind \"F9\" \"echo Quickloading...; wait; load quick\"; \
bind \"F10\" \"quit\"; \
bind \"F12\" \"screenshot\"; \
bind \"INS\" \"+klook\"; \
bind \"DEL\" \"+lookdown\"; \
bind \"PGDN\" \"+lookup\"; \
bind \"END\" \"centerview\"; \
bind \"MOUSE1\" \"+attack\"; \
bind \"MOUSE2\" \"+forward\"; \
bind \"MOUSE3\" \"+speed\"; \
bind \"PAUSE\" \"pause\"; \
bind \"MWHEELUP\" \"impulse 10\"; \
bind \"MWHEELDOWN\" \"impulse 12\"; \
"

==> quore-0.2.6.tgz: quore-0.2.6/include/binds.h <==
#define ENGINE_BINDS " \
bind \"TAB\" \"+showscores\"; \
bind \"ENTER\" \"+jump\"; \
bind \"ESCAPE\" \"togglemenu\"; \
bind \"~\" \"toggleconsole\"; \
bind \"+\" \"sizeup\"; \
bind \"=\" \"sizeup\"; \
bind \"-\" \"sizedown\"; \
bind \"0\" \"impulse 0\"; \
bind \"1\" \"impulse 1\"; \
bind \"2\" \"impulse 2\"; \
bind \"3\" \"impulse 3\"; \
bind \"4\" \"impulse 4\"; \
bind \"5\" \"impulse 5\"; \
bind \"6\" \"impulse 6\"; \
bind \"7\" \"impulse 7\"; \
bind \"8\" \"impulse 8\"; \
bind \"\\\" \"+mlook\"; \
bind \"`\" \"toggleconsole\"; \
bind \"a\" \"+moveleft\"; \
bind \"d\" \"+moveright\"; \
bind \"s\" \"+forward\"; \
bind \"t\" \"messagemode\"; \
bind \"z\" \"+back\"; \
bind \"UPARROW\" \"+forward\"; \
bind \"DOWNARROW\" \"+back\"; \
bind \"LEFTARROW\" \"+moveleft\"; \
bind \"RIGHTARROW\" \"+moveright\"; \
bind \"ALT\" \"+strafe\"; \
bind \"CTRL\" \"+jump\"; \
bind \"SHIFT\" \"+speed\"; \
bind \"SPACE\" \"+jump\"; \
bind \"F1\" \"help\"; \
bind \"F2\" \"menu_save\"; \
bind \"F3\" \"menu_load\"; \
bind \"F4\" \"menu_options\"; \
bind \"F5\" \"menu_multiplayer\"; \
bind \"F6\" \"echo Quicksaving...; wait; save quick\"; \
bind \"F9\" \"echo Quickloading...; wait; load quick\"; \
bind \"F10\" \"quit\"; \
bind \"F11\" \"menu_maps\"; \
bind \"F12\" \"screenshot\"; \
bind \"INS\" \"+klook\"; \
bind \"DEL\" \"+lookdown\"; \
bind \"PGDN\" \"+lookup\"; \
bind \"END\" \"centerview\"; \
bind \"MOUSE1\" \"+attack\"; \
bind \"MOUSE3\" \"+speed\"; \
bind \"PAUSE\" \"pause\"; \
bind \"MWHEELUP\" \"impulse 10\"; \
bind \"MWHEELDOWN\" \"impulse 12\"; \
"
